@@ -10,7 +10,7 @@
 
 module RbConfig
   RUBY_VERSION.start_with?("3.2.") or
-    raise "ruby lib version (3.2.4) doesn't match executable version (#{RUBY_VERSION})"
+    raise "ruby lib version (3.2.5) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
   TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/3.2/aarch64-openbsd")
@@ -21,9 +21,9 @@ module RbConfig
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "3"
   CONFIG["MINOR"] = "2"
-  CONFIG["TEENY"] = "4"
-  CONFIG["PATCHLEVEL"] = "170"
-  CONFIG["INSTALL"] = '/build/tmp/pobj//ruby-3.2.4/bin/install -c'
+  CONFIG["TEENY"] = "5"
+  CONFIG["PATCHLEVEL"] = "208"
+  CONFIG["INSTALL"] = '/usr/obj/ports/ruby-3.2.5/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)32"
@@ -158,9 +158,9 @@ module RbConfig
   CONFIG["DOXYGEN"] = ""
   CONFIG["DOT"] = ""
   CONFIG["MKDIR_P"] = "mkdir -p"
-  CONFIG["INSTALL_DATA"] = "/build/tmp/pobj//ruby-3.2.4/bin/install -c -m 644"
-  CONFIG["INSTALL_SCRIPT"] = "/build/tmp/pobj//ruby-3.2.4/bin/install -c -m 755"
-  CONFIG["INSTALL_PROGRAM"] = "/build/tmp/pobj//ruby-3.2.4/bin/install -c  -m 755"
+  CONFIG["INSTALL_DATA"] = "/usr/obj/ports/ruby-3.2.5/bin/install -c -m 644"
+  CONFIG["INSTALL_SCRIPT"] = "/usr/obj/ports/ruby-3.2.5/bin/install -c -m 755"
+  CONFIG["INSTALL_PROGRAM"] = "/usr/obj/ports/ruby-3.2.5/bin/install -c  -m 755"
   CONFIG["SET_MAKE"] = ""
   CONFIG["LN_S"] = "ln -s"
   CONFIG["DLLWRAP"] = ""
@@ -168,7 +168,7 @@ module RbConfig
   CONFIG["ASFLAGS"] = ""
   CONFIG["ARFLAGS"] = "rcD "
   CONFIG["try_header"] = ""
-  CONFIG["CC_VERSION_MESSAGE"] = "OpenBSD clang version 16.0.6\nTarget: aarch64-unknown-openbsd7.5\nThread model: posix\nInstalledDir: /usr/bin"
+  CONFIG["CC_VERSION_MESSAGE"] = "OpenBSD clang version 16.0.6\nTarget: aarch64-unknown-openbsd7.6\nThread model: posix\nInstalledDir: /usr/bin"
   CONFIG["CC_VERSION"] = "$(CC) --version"
   CONFIG["MJIT_CC"] = "/usr/bin/cc"
   CONFIG["CSRCFLAG"] = ""
@@ -190,12 +190,12 @@ module RbConfig
   CONFIG["NM"] = "nm"
   CONFIG["LD"] = "ld"
   CONFIG["CXX"] = "c++"
-  CONFIG["AS"] = ""
+  CONFIG["AS"] = "gas"
   CONFIG["AR"] = "ar"
   CONFIG["CC"] = "cc"
   CONFIG["wasmoptflags"] = ""
   CONFIG["WASMOPT"] = ""
-  CONFIG["target_os"] = "openbsd7.5"
+  CONFIG["target_os"] = "openbsd7.6"
   CONFIG["target_vendor"] = "unknown"
   CONFIG["target_cpu"] = "aarch64"
   CONFIG["target"] = "$(target_cpu)-$(target_vendor)-$(target_os)"
@@ -203,16 +203,16 @@ module RbConfig
   CONFIG["host_vendor"] = "$(target_vendor)"
   CONFIG["host_cpu"] = "$(target_cpu)"
   CONFIG["host"] = "$(target)"
-  CONFIG["build_os"] = "openbsd7.5"
+  CONFIG["build_os"] = "openbsd7.6"
   CONFIG["build_vendor"] = "unknown"
   CONFIG["build_cpu"] = "aarch64"
-  CONFIG["build"] = "aarch64-unknown-openbsd7.5"
+  CONFIG["build"] = "aarch64-unknown-openbsd7.6"
   CONFIG["RUBY_VERSION_NAME"] = "$(RUBY_BASE_NAME)-$(ruby_version)"
   CONFIG["RUBYW_BASE_NAME"] = "rubyw"
   CONFIG["RUBY_BASE_NAME"] = "ruby"
   CONFIG["RUBY_PROGRAM_VERSION"] = "$(MAJOR).$(MINOR).$(TEENY)"
   CONFIG["RUBY_API_VERSION"] = "$(MAJOR).$(MINOR)"
-  CONFIG["HAVE_GIT"] = "yes"
+  CONFIG["HAVE_GIT"] = "no"
   CONFIG["GIT"] = "git"
   CONFIG["cxxflags"] = ""
   CONFIG["cppflags"] = ""
