@@ -1,16 +1,16 @@
+# frozen_string_literal: false
 #
 #   irb/locale.rb - internationalization module
 #   	$Release Version: 0.9.6$
-#   	$Revision: 31201 $
+#   	$Revision$
 #   	by Keiju ISHITSUKA(keiju@ruby-lang.org)
 #
 # --
 #
 #
 #
-module IRB
+module IRB # :nodoc:
   class Locale
-    @RCS_ID='-$Id: locale.rb 31201 2011-03-28 13:40:53Z yugui $-'
 
     LOCALE_NAME_RE = %r[
       (?<language>[[:alpha:]]{2,3})
@@ -21,32 +21,38 @@ module IRB
     LOCALE_DIR = "/lc/"
 
     @@legacy_encoding_alias_map = {}.freeze
+    @@loaded = []
 
     def initialize(locale = nil)
+      @override_encoding = nil
       @lang = @territory = @encoding_name = @modifier = nil
       @locale = locale || ENV["IRB_LANG"] || ENV["LC_MESSAGES"] || ENV["LC_ALL"] || ENV["LANG"] || "C"
       if m = LOCALE_NAME_RE.match(@locale)
-	@lang, @territory, @encoding_name, @modifier = m[:language], m[:territory], m[:codeset], m[:modifier]
+        @lang, @territory, @encoding_name, @modifier = m[:language], m[:territory], m[:codeset], m[:modifier]
 
-	if @encoding_name
-	  begin load 'irb/encoding_aliases.rb'; rescue LoadError; end
-	  if @encoding = @@legacy_encoding_alias_map[@encoding_name]
-	    warn "%s is obsolete. use %s" % ["#{@lang}_#{@territory}.#{@encoding_name}", "#{@lang}_#{@territory}.#{@encoding.name}"]
-	  end
-	  @encoding = Encoding.find(@encoding_name) rescue nil
-	end
+        if @encoding_name
+          begin load 'irb/encoding_aliases.rb'; rescue LoadError; end
+          if @encoding = @@legacy_encoding_alias_map[@encoding_name]
+            warn(("%s is obsolete. use %s" % ["#{@lang}_#{@territory}.#{@encoding_name}", "#{@lang}_#{@territory}.#{@encoding.name}"]), uplevel: 1)
+          end
+          @encoding = Encoding.find(@encoding_name) rescue nil
+        end
       end
       @encoding ||= (Encoding.find('locale') rescue Encoding::ASCII_8BIT)
     end
 
-    attr_reader :lang, :territory, :encoding, :modifieer
+    attr_reader :lang, :territory, :modifier
+
+    def encoding
+      @override_encoding || @encoding
+    end
 
     def String(mes)
       mes = super(mes)
-      if @encoding
-	mes.encode(@encoding, undef: :replace)
+      if encoding
+        mes.encode(encoding, undef: :replace)
       else
-	mes
+        mes
       end
     end
 
@@ -83,22 +89,22 @@ module IRB
 
       case file
       when /\.rb$/
-	begin
-	  load(file, priv)
-	  $".push file
-	  return true
-	rescue LoadError
-	end
+        begin
+          load(file, priv)
+          $".push file
+          return true
+        rescue LoadError
+        end
       when /\.(so|o|sl)$/
-	return super
+        return super
       end
 
       begin
-	load(f = file + ".rb")
-	$".push f  #"
-	return true
+        load(f = file + ".rb")
+        $".push f  #"
+        return true
       rescue LoadError
-	return ruby_require(file)
+        return ruby_require(file)
       end
     end
 
@@ -107,7 +113,10 @@ module IRB
     def load(file, priv=nil)
       found = find(file)
       if found
-        return real_load(found, priv)
+        unless @@loaded.include?(found)
+          @@loaded << found # cache
+          return real_load(found, priv)
+        end
       else
         raise LoadError, "No such file to load -- #{file}"
       end
@@ -129,14 +138,14 @@ module IRB
     def real_load(path, priv)
       src = MagicFile.open(path){|f| f.read}
       if priv
-	eval("self", TOPLEVEL_BINDING).extend(Module.new {eval(src, nil, path)})
+        eval("self", TOPLEVEL_BINDING).extend(Module.new {eval(src, nil, path)})
       else
-	eval(src, TOPLEVEL_BINDING, path)
+        eval(src, TOPLEVEL_BINDING, path)
       end
     end
 
     # @param paths load paths in which IRB find a localized file.
-    # @param dir directory 
+    # @param dir directory
     # @param file basename to be localized
     #
     # typically, for the parameters and a <path> in paths, it searches
@@ -161,20 +170,20 @@ module IRB
 
     def each_sublocale
       if @lang
-	if @territory
-	  if @encoding_name
-	    yield "#{@lang}_#{@territory}.#{@encoding_name}@#{@modifier}" if @modifier
-	    yield "#{@lang}_#{@territory}.#{@encoding_name}"
-	  end
-	  yield "#{@lang}_#{@territory}@#{@modifier}" if @modifier
-	  yield "#{@lang}_#{@territory}"
-	end
+        if @territory
+          if @encoding_name
+            yield "#{@lang}_#{@territory}.#{@encoding_name}@#{@modifier}" if @modifier
+            yield "#{@lang}_#{@territory}.#{@encoding_name}"
+          end
+          yield "#{@lang}_#{@territory}@#{@modifier}" if @modifier
+          yield "#{@lang}_#{@territory}"
+        end
         if @encoding_name
           yield "#{@lang}.#{@encoding_name}@#{@modifier}" if @modifier
           yield "#{@lang}.#{@encoding_name}"
         end
-	yield "#{@lang}@#{@modifier}" if @modifier
-	yield "#{@lang}"
+        yield "#{@lang}@#{@modifier}" if @modifier
+        yield "#{@lang}"
       end
       yield nil
     end
