@@ -29,8 +29,9 @@
 # - Open3.pipeline : run a pipeline and wait for its completion
 #
 
+require 'open3/version'
+
 module Open3
-  VERSION = "0.1.1"
 
   # Open stdin, stdout, and stderr streams and start external executable.
   # In addition, a thread to wait for the started process is created.
@@ -758,3 +759,6 @@ module Open3
   end
 
 end
+
+# JRuby uses different popen logic on Windows, require it here to reuse wrapper methods above.
+require 'open3/jruby_windows' if RUBY_ENGINE == 'jruby' && JRuby::Util::ON_WINDOWS
