@@ -1,4 +1,4 @@
-# frozen_string_literal: false
+# frozen_string_literal: true
 module RDoc
 
   ##
@@ -25,6 +25,7 @@ module RDoc
     "rb_cObject"           => "Object",
     "rb_cProc"             => "Proc",
     "rb_cRange"            => "Range",
+    "rb_cRefinement"       => "Refinement",
     "rb_cRegexp"           => "Regexp",
     "rb_cRubyVM"           => "RubyVM",
     "rb_cSocket"           => "Socket",
@@ -35,7 +36,7 @@ module RDoc
     "rb_cTime"             => "Time",
     "rb_cTrueClass"        => "TrueClass",
 
-    "rb_eArgError"         => "ArgError",
+    "rb_eArgError"         => "ArgumentError",
     "rb_eEOFError"         => "EOFError",
     "rb_eException"        => "Exception",
     "rb_eFatal"            => "fatal",
@@ -45,8 +46,8 @@ module RDoc
     "rb_eInterrupt"        => "Interrupt",
     "rb_eLoadError"        => "LoadError",
     "rb_eNameError"        => "NameError",
-    "rb_eNoMemError"       => "NoMemError",
-    "rb_eNotImpError"      => "NotImpError",
+    "rb_eNoMemError"       => "NoMemoryError",
+    "rb_eNotImpError"      => "NotImplementedError",
     "rb_eRangeError"       => "RangeError",
     "rb_eRuntimeError"     => "RuntimeError",
     "rb_eScriptError"      => "ScriptError",
@@ -57,7 +58,7 @@ module RDoc
     "rb_eSystemCallError"  => "SystemCallError",
     "rb_eSystemExit"       => "SystemExit",
     "rb_eTypeError"        => "TypeError",
-    "rb_eZeroDivError"     => "ZeroDivError",
+    "rb_eZeroDivError"     => "ZeroDivisionError",
 
     "rb_mComparable"       => "Comparable",
     "rb_mEnumerable"       => "Enumerable",
