@@ -1,4 +1,5 @@
 # frozen_string_literal: true
+
 ##
 # Used internally to indicate that a dependency conflicted
 # with a spec that would be activated.
@@ -27,9 +28,9 @@ class Gem::Resolver::Conflict
   end
 
   def ==(other) # :nodoc:
-    self.class === other and
-      @dependency == other.dependency and
-      @activated  == other.activated  and
+    self.class === other &&
+      @dependency == other.dependency &&
+      @activated  == other.activated  &&
       @failed_dep == other.failed_dep
   end
 
@@ -65,7 +66,7 @@ class Gem::Resolver::Conflict
 
       matching = matching % [
         dependency,
-        alternates.join(', '),
+        alternates.join(", "),
       ]
     end
 
@@ -97,21 +98,21 @@ class Gem::Resolver::Conflict
   end
 
   def pretty_print(q) # :nodoc:
-    q.group 2, '[Dependency conflict: ', ']' do
+    q.group 2, "[Dependency conflict: ", "]" do
       q.breakable
 
-      q.text 'activated '
+      q.text "activated "
       q.pp @activated
 
       q.breakable
-      q.text ' dependency '
+      q.text " dependency "
       q.pp @dependency
 
       q.breakable
       if @dependency == @failed_dep
-        q.text ' failed'
+        q.text " failed"
       else
-        q.text ' failed dependency '
+        q.text " failed dependency "
         q.pp @failed_dep
       end
     end
@@ -139,7 +140,7 @@ class Gem::Resolver::Conflict
       end
     end
 
-    path = ['user request (gem command or Gemfile)'] if path.empty?
+    path = ["user request (gem command or Gemfile)"] if path.empty?
 
     path
   end
