@@ -1,4 +1,5 @@
-# frozen_string_literal: false
+# frozen_string_literal: true
+
 ##
 # The RequirementList is used to hold the requirements being considered
 # while resolving a set of gems.
@@ -7,7 +8,6 @@
 # first.
 
 class Gem::Resolver::RequirementList
-
   include Enumerable
 
   ##
@@ -18,7 +18,7 @@ class Gem::Resolver::RequirementList
     @list = []
   end
 
-  def initialize_copy other # :nodoc:
+  def initialize_copy(other) # :nodoc:
     @exact = @exact.dup
     @list = @list.dup
   end
